@@ -13,6 +13,7 @@ from ome_types import OME
 
 from . import dimensions, exceptions, transforms, types
 from .formats import FORMAT_IMPLEMENTATIONS, READER_TO_INSTALL
+from .image_container import ImageContainer
 from .metadata import utils as metadata_utils
 from .readers import TiffGlobReader
 from .readers.reader import Reader
@@ -32,7 +33,7 @@ def _load_reader(reader_path: str) -> Type[Reader]:
     return getattr(loaded_mod, reader_name)
 
 
-class AICSImage:
+class AICSImage(ImageContainer):
     """
     AICSImage takes microscopy image data types (files or arrays) of varying
     dimensions ("ZYX", "TCZYX", "CYX") and reads them as consistent 5D "TCZYX"
@@ -58,6 +59,9 @@ class AICSImage:
         `M` dimension for tiles.
         If image is not a mosaic, data won't be stitched or have an `M` dimension for
         tiles.
+    fs_kwargs: Dict[str, Any]
+        Any specific keyword arguments to pass down to the fsspec created filesystem.
+        Default: {}
     kwargs: Any
         Extra keyword arguments that will be passed down to the reader subclass.
 
@@ -140,7 +144,11 @@ class AICSImage:
                 pass
 
     @staticmethod
-    def determine_reader(image: types.ImageLike, **kwargs: Any) -> Type[Reader]:
+    def determine_reader(
+        image: types.ImageLike,
+        fs_kwargs: Dict[str, Any] = {},
+        **kwargs: Any,
+    ) -> Type[Reader]:
         """
         Cheaply check to see if a given file is a recognized type and return the
         appropriate reader for the image.
@@ -165,7 +173,7 @@ class AICSImage:
 
         # Try reader detection based off of file path extension
         if isinstance(image, (str, Path)):
-            _, path = pathlike_to_fs(image, enforce_exists=True)
+            _, path = pathlike_to_fs(image, enforce_exists=True, fs_kwargs=fs_kwargs)
 
             # Check for extension in FORMAT_IMPLEMENTATIONS
             for format_ext, readers in FORMAT_IMPLEMENTATIONS.items():
@@ -173,7 +181,10 @@ class AICSImage:
                     for reader in readers:
                         try:
                             ReaderClass = _load_reader(reader)
-                            if ReaderClass.is_supported_image(image):
+                            if ReaderClass.is_supported_image(
+                                image,
+                                fs_kwargs=fs_kwargs,
+                            ):
                                 return ReaderClass
                         except Exception as e:
                             log.warning(
@@ -186,7 +197,11 @@ class AICSImage:
         # Or provided an in-memory object (arraylike)
         for ReaderClass in AICSImage.SUPPORTED_READERS:
             try:
-                if ReaderClass.is_supported_image(image, **kwargs):  # type: ignore
+                if ReaderClass.is_supported_image(
+                    image,
+                    fs_kwargs=fs_kwargs,
+                    **kwargs,  # type: ignore
+                ):
                     return ReaderClass
             except Exception:
                 pass
@@ -241,17 +256,18 @@ class AICSImage:
         image: types.ImageLike,
         reader: Optional[Type[Reader]] = None,
         reconstruct_mosaic: bool = True,
+        fs_kwargs: Dict[str, Any] = {},
         **kwargs: Any,
     ):
         if reader is None:
             # Determine reader class and create dask delayed array
-            ReaderClass = self.determine_reader(image, **kwargs)
+            ReaderClass = self.determine_reader(image, fs_kwargs=fs_kwargs, **kwargs)
         else:
             # Init reader
             ReaderClass = reader
 
         # Init and store reader
-        self._reader = ReaderClass(image, **kwargs)
+        self._reader = ReaderClass(image, fs_kwargs=fs_kwargs, **kwargs)
 
         # Store delayed modifiers
         self._reconstruct_mosaic = reconstruct_mosaic
@@ -363,7 +379,7 @@ class AICSImage:
         # Pull the data with the appropriate dimensions
         data = transforms.reshape_data(
             data=arr.data,
-            given_dims="".join(arr.dims),  # type: ignore
+            given_dims="".join(arr.dims),
             return_dims=return_dims,
         )
 
@@ -385,7 +401,7 @@ class AICSImage:
         return xr.DataArray(
             data,
             dims=tuple([d for d in return_dims]),
-            coords=coords,  # type: ignore
+            coords=coords,
             attrs=arr.attrs,
         )
 
@@ -702,6 +718,96 @@ class AICSImage:
             **kwargs,
         )
 
+    def get_stack(self, **kwargs: Any) -> np.ndarray:
+        """
+        Get all scenes stacked in to a single array.
+
+        Returns
+        -------
+        stack: np.ndarray
+            The fully stacked array. This can be 6+ dimensions with Scene being
+            the first dimension.
+        kwargs: Any
+            Extra keyword arguments that will be passed down to the
+            generate stack function.
+
+        See Also
+        --------
+        aicsimageio.transforms.generate_stack:
+            Underlying function for generating various scene stacks.
+        """
+        return transforms.generate_stack(self, "data", **kwargs)
+
+    def get_dask_stack(self, **kwargs: Any) -> da.Array:
+        """
+        Get all scenes stacked in to a single array.
+
+        Returns
+        -------
+        stack: da.Array
+            The fully stacked array. This can be 6+ dimensions with Scene being
+            the first dimension.
+        kwargs: Any
+            Extra keyword arguments that will be passed down to the
+            generate stack function.
+
+        See Also
+        --------
+        aicsimageio.transforms.generate_stack:
+            Underlying function for generating various scene stacks.
+        """
+        return transforms.generate_stack(self, "dask_data", **kwargs)
+
+    def get_xarray_stack(self, **kwargs: Any) -> xr.DataArray:
+        """
+        Get all scenes stacked in to a single array.
+
+        Returns
+        -------
+        stack: xr.DataArray
+            The fully stacked array. This can be 6+ dimensions with Scene being
+            the first dimension.
+        kwargs: Any
+            Extra keyword arguments that will be passed down to the
+            generate stack function.
+
+        See Also
+        --------
+        aicsimageio.transforms.generate_stack:
+            Underlying function for generating various scene stacks.
+
+        Notes
+        -----
+        When requesting an xarray stack, the first scene's coordinate planes
+        are used for the returned xarray DataArray object coordinate planes.
+        """
+        return transforms.generate_stack(self, "xarray_data", **kwargs)
+
+    def get_xarray_dask_stack(self, **kwargs: Any) -> xr.DataArray:
+        """
+        Get all scenes stacked in to a single array.
+
+        Returns
+        -------
+        stack: xr.DataArray
+            The fully stacked array. This can be 6+ dimensions with Scene being
+            the first dimension.
+        kwargs: Any
+            Extra keyword arguments that will be passed down to the
+            generate stack function.
+
+        See Also
+        --------
+        aicsimageio.transforms.generate_stack:
+            Underlying function for generating various scene stacks.
+
+        Notes
+        -----
+        When requesting an xarray stack, the first scene's coordinate planes
+        are used for the returned xarray DataArray object coordinate planes.
+        """
+        return transforms.generate_stack(self, "xarray_dask_data", **kwargs)
+
     @property
     def metadata(self) -> Any:
         """
