@@ -1,7 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from typing import ItemsView, Iterable, Tuple, Union
+from collections.abc import Sequence as seq
+from typing import Collection, ItemsView, Sequence, Tuple, Union
 
 ###############################################################################
 
@@ -63,14 +64,14 @@ REQUIRED_CHUNK_DIMS = [
 
 
 class Dimensions:
-    def __init__(self, dims: Union[str, Iterable], shape: Tuple[int, ...]):
+    def __init__(self, dims: Collection[str], shape: Tuple[int, ...]):
         """
         A general object for managing the pairing of dimension name and dimension size.
 
         Parameters
         ----------
-        dims: Union[str, Iterable]
-            An ordered string or iterable of the dimensions to pair with their sizes.
+        dims: Collection[str]
+            An ordered string or collection of the dimensions to pair with their sizes.
         shape: Tuple[int, ...]
             An ordered tuple of the dimensions sizes to pair with their names.
 
@@ -78,9 +79,24 @@ class Dimensions:
         --------
         >>> dims = Dimensions("TCZYX", (1, 4, 75, 624, 924))
         ... dims.X
+        ... dims['T', 'X']
         """
+        # zip(strict=True) only in Python 3.10
+        # Check equal length dims and shape
+        if len(dims) != len(shape):
+            raise ValueError(
+                f"Number of dimensions provided ({len(dims)} -- '{dims}') "
+                f"does not match shape size provided ({len(shape)} -- '{shape}')."
+            )
+
         # Make dims a string
         if not isinstance(dims, str):
+            if any([len(c) != 1 for c in dims]):
+                raise ValueError(
+                    f"When providing a list of dimension strings, "
+                    f"each dimension may only be a single character long "
+                    f"(received: '{dims}')."
+                )
             dims = "".join(dims)
 
         # Store order and shape
@@ -121,3 +137,29 @@ class Dimensions:
 
     def __repr__(self) -> str:
         return str(self)
+
+    def __getitem__(self, key: Union[str, Sequence[str]]) -> Tuple[int, ...]:
+        if isinstance(key, str):
+            if key not in self._order:
+                raise IndexError(f"{key} not in {self._order}")
+            return (self._dims_shape[key],)
+        elif isinstance(key, seq) and all(isinstance(k, str) for k in key):
+            invalid_dims = []
+            for k in key:
+                if k not in self._order:
+                    invalid_dims.append(k)
+            if len(invalid_dims) == 0:
+                return tuple(self._dims_shape[k] for k in key)
+            else:
+                raise IndexError(f"{', '.join(invalid_dims)} not in {self._order}")
+        else:
+            raise TypeError(
+                f"Key must be a string or list of strings but got type {type(key)}"
+            )
+
+    def __setattr__(self, __name: str, __value: int) -> None:
+        super().__setattr__(__name, __value)
+
+    def __getattr__(self, __name: str) -> int:
+        # TODO: Py310 __match_args__ for better typing
+        return super().__getattribute__(__name)
