@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import warnings
+import logging
 import xml.etree.ElementTree as ET
 from copy import copy
 from pathlib import Path
@@ -33,6 +33,10 @@ except ImportError:
 
 ###############################################################################
 
+log = logging.getLogger(__name__)
+
+###############################################################################
+
 CZI_SAMPLES_DIM_CHAR = "A"
 CZI_BLOCK_DIM_CHAR = "B"
 CZI_SCENE_DIM_CHAR = "S"
@@ -44,6 +48,7 @@ PIXEL_DICT = {
     "gray8": np.uint8,
     "gray16": np.uint16,
     "gray32": np.uint32,
+    "gray32float": np.float32,
     "bgr24": np.uint8,
     "bgr48": np.uint16,
     "invalid": np.uint8,
@@ -71,6 +76,9 @@ class CziReader(Reader):
     include_subblock_metadata: bool
         Whether to append metadata from the subblocks to the rest of the embeded
         metadata.
+    fs_kwargs: Dict[str, Any]
+        Any specific keyword arguments to pass down to the fsspec created filesystem.
+        Default: {}
 
     Notes
     -----
@@ -87,7 +95,7 @@ class CziReader(Reader):
                 )
 
             with fs.open(path) as open_resource:
-                CziFile(open_resource)
+                CziFile(open_resource.f)
                 return True
 
         except RuntimeError:
@@ -97,11 +105,15 @@ class CziReader(Reader):
         self,
         image: types.PathLike,
         chunk_dims: Union[str, List[str]] = DEFAULT_CHUNK_DIMS,
-        chunk_by_dims: Optional[Union[str, List[str]]] = None,
         include_subblock_metadata: bool = False,
+        fs_kwargs: Dict[str, Any] = {},
     ):
         # Expand details of provided image
-        self._fs, self._path = io_utils.pathlike_to_fs(image, enforce_exists=True)
+        self._fs, self._path = io_utils.pathlike_to_fs(
+            image,
+            enforce_exists=True,
+            fs_kwargs=fs_kwargs,
+        )
 
         # Catch non-local file system
         if not isinstance(self._fs, LocalFileSystem):
@@ -110,15 +122,6 @@ class CziReader(Reader):
                 f"Received URI: {self._path}, which points to {type(self._fs)}."
             )
 
-        # Handle deprecated parameter
-        if chunk_by_dims is not None:
-            warnings.warn(
-                "CziReader parameter 'chunk_by_dims' has been renamed to 'chunk_dims'. "
-                "'chunk_by_dims' will be removed in aicsimageio>=4.1.",
-                DeprecationWarning,
-            )
-            chunk_dims = chunk_by_dims
-
         # Store params
         if isinstance(chunk_dims, str):
             chunk_dims = list(chunk_dims)
@@ -141,7 +144,7 @@ class CziReader(Reader):
     def mapped_dims(self) -> str:
         if self._mapped_dims is None:
             with self._fs.open(self._path) as open_resource:
-                czi = CziFile(open_resource)
+                czi = CziFile(open_resource.f)
                 self._mapped_dims = CziReader._fix_czi_dims(czi.dims)
 
         return self._mapped_dims
@@ -158,7 +161,7 @@ class CziReader(Reader):
     def scenes(self) -> Tuple[str, ...]:
         if self._scenes is None:
             with self._fs.open(self._path) as open_resource:
-                czi = CziFile(open_resource)
+                czi = CziFile(open_resource.f)
                 xpath_str = "./Metadata/Information/Image/Dimensions/S/Scenes/Scene"
                 meta_scenes = czi.meta.findall(xpath_str)
                 scene_names: List[str] = []
@@ -186,6 +189,27 @@ class CziReader(Reader):
                 # If the scene is implicit just assign it name Scene:0
                 if len(scene_names) < 1:
                     scene_names = [metadata_utils.generate_ome_image_id(0)]
+                else:
+                    # reconcile scene list against the dims shape
+                    dims_shape = czi.get_dims_shape()
+                    if len(scene_names) != len(dims_shape) and czi.shape_is_consistent:
+                        dims_shape_dict = dims_shape[0]
+                        scene_range = dims_shape_dict.get(CZI_SCENE_DIM_CHAR)
+                        if scene_range is not None:
+                            scene_names = scene_names[scene_range[0] : scene_range[1]]
+                        else:
+                            # If this is the root node of a split multiscene czi,
+                            # then the scene_range could be None because the dims_shape
+                            # will be effectively empty.
+                            # We do not currently support loading multi-file split
+                            # scene CZI files
+                            log.warning(
+                                "CZI file appears to contain multiple scenes but "
+                                "dimension data is not available in this file. "
+                                "Root node of split multi-scene CZI files are not "
+                                "supported by CziReader."
+                            )
+
                 self._scenes = tuple(scene_names)
 
         return self._scenes
@@ -218,6 +242,35 @@ class CziReader(Reader):
         dims_shape_dict.pop(CZI_SCENE_DIM_CHAR, None)
         return dims_shape_dict
 
+    @staticmethod
+    def _adjust_scene_index(
+        dims_shape: List[Dict], scene_index: int, consistent: bool
+    ) -> int:
+        """
+        This function modifies a scene index to be an offset into the true scene
+        indices reported by the czi file
+
+        Parameters
+        ----------
+        dims_shape: List[Dict]
+            a list of dictionaries, generated by `get_dims_shape()`
+        scene_index: int
+            the index of the scene being used
+        consistent: bool
+            true if the dictionaries are consistent could be represented
+            compactly (dims_shape with length 1)
+
+        Returns
+        -------
+        An int representing the scene index to use in a true libCZI dimension
+        """
+        dims_shape_index = 0 if consistent else scene_index
+        dims_shape_dict = dims_shape[dims_shape_index]
+        scene_range = dims_shape_dict.get(CZI_SCENE_DIM_CHAR)
+        if scene_range is None:
+            return scene_index
+        return scene_range[0] + scene_index
+
     @staticmethod
     def _read_chunk_from_image(
         fs: AbstractFileSystem,
@@ -263,12 +316,15 @@ class CziReader(Reader):
         if read_dims is None:
             read_dims = {}
 
-        # Get current scene read dims
-        read_dims[CZI_SCENE_DIM_CHAR] = scene
-
         # Init czi
         with fs.open(path) as open_resource:
-            czi = CziFile(open_resource)
+            czi = CziFile(open_resource.f)
+
+            # Get current scene read dims
+            adjusted_scene_index = CziReader._adjust_scene_index(
+                czi.get_dims_shape(), scene, czi.shape_is_consistent
+            )
+            read_dims[CZI_SCENE_DIM_CHAR] = adjusted_scene_index
 
             # Read image
             data, dims = czi.read_image(**read_dims)
@@ -467,11 +523,30 @@ class CziReader(Reader):
             if scene_index < len(img_sets):
                 img = img_sets[scene_index]
 
-            # Construct channel list
+            # Construct channel name list
             scene_channel_list = []
             channels = img.findall("./Channel")
-            for channel in channels:
-                channel_name = channel.attrib["Name"]
+            for i, channel in enumerate(channels):
+                # Id is required, Name is not.
+                # But we prefer to use Name if it is present
+                channel_name = channel.attrib.get("Name")
+                channel_id = channel.attrib.get("Id")
+                if channel_name is None:
+                    # TODO: the next best guess is to see if there's a Name in
+                    # DisplaySetting/Channels/Channel
+                    # xpath_str = "./Metadata/DisplaySetting/Channels"
+                    # displaysetting_channels = xml.findall(xpath_str)
+                    # ds_channels = displaysetting_channels[0].findall("./Channel")
+                    # to find matching channel must match on Id attribute or if Id not
+                    # present, just on collection index i
+                    # If we didn't find a match this way, just use the Id as the name
+                    channel_name = channel_id
+                if channel_name is None:
+                    # This is actually an error because Id was required by the spec
+                    channel_name = metadata_utils.generate_ome_channel_id(
+                        str(scene_index), str(i)
+                    )
+
                 scene_channel_list.append(channel_name)
 
             # Attach channel names to coords
@@ -535,7 +610,7 @@ class CziReader(Reader):
             The file could not be read or is not supported.
         """
         with self._fs.open(self._path) as open_resource:
-            czi = CziFile(open_resource)
+            czi = CziFile(open_resource.f)
 
             dims_shape = CziReader._dims_shape_to_scene_dims_shape(
                 dims_shape=czi.get_dims_shape(),
@@ -576,7 +651,7 @@ class CziReader(Reader):
                 return xr.DataArray(
                     image_data,
                     dims=img_dims_list,
-                    coords=coords,  # type: ignore
+                    coords=coords,
                     attrs={constants.METADATA_UNPROCESSED: meta},
                 )
 
@@ -596,7 +671,7 @@ class CziReader(Reader):
             The file could not be read or is not supported.
         """
         with self._fs.open(self._path) as open_resource:
-            czi = CziFile(open_resource)
+            czi = CziFile(open_resource.f)
             dims_shape = CziReader._dims_shape_to_scene_dims_shape(
                 dims_shape=czi.get_dims_shape(),
                 scene_index=self.current_scene_index,
@@ -626,7 +701,7 @@ class CziReader(Reader):
             return xr.DataArray(
                 image_data,
                 dims=[d for d in self.mapped_dims],
-                coords=coords,  # type: ignore
+                coords=coords,
                 attrs={constants.METADATA_UNPROCESSED: meta},
             )
 
@@ -714,7 +789,7 @@ class CziReader(Reader):
     def _construct_mosaic_xarray(self, data: types.ArrayLike) -> xr.DataArray:
         # Get max of mosaic positions from lif
         with self._fs.open(self._path) as open_resource:
-            czi = CziFile(open_resource)
+            czi = CziFile(open_resource.f)
             dims_shape = CziReader._dims_shape_to_scene_dims_shape(
                 dims_shape=czi.get_dims_shape(),
                 scene_index=self.current_scene_index,
@@ -806,7 +881,10 @@ class CziReader(Reader):
             # so simply run array construct
             self.dask_data
 
-        return self._px_sizes  # type: ignore
+        if self._px_sizes is None:
+            raise ValueError("Pixel sizes weren't created as a part of image reading")
+
+        return self._px_sizes
 
     def get_mosaic_tile_position(self, mosaic_tile_index: int) -> Tuple[int, int]:
         """
@@ -836,7 +914,7 @@ class CziReader(Reader):
 
         # Get max of mosaic positions from lif
         with self._fs.open(self._path) as open_resource:
-            czi = CziFile(open_resource)
+            czi = CziFile(open_resource.f)
 
             bboxes = czi.get_all_mosaic_tile_bounding_boxes(S=self.current_scene_index)
             bbox = list(bboxes.values())[mosaic_tile_index]
